@@ -277,8 +277,8 @@ netk_pager_size_request (GtkWidget * widget, GtkRequisition * requisition)
     if (pager->priv->orientation == GTK_ORIENTATION_VERTICAL)
     {
         screen_aspect =
-            (double) netk_screen_get_width (pager->priv->screen) /
-            (double) netk_screen_get_height (pager->priv->screen);
+            (double) netk_screen_get_height (pager->priv->screen) /
+            (double) netk_screen_get_width (pager->priv->screen);
 
         /* TODO: Handle NETK_PAGER_DISPLAY_NAME for this case */
 
@@ -561,6 +561,7 @@ get_window_rect (NetkWindow * window,
     double width_ratio, height_ratio;
     int x, y, width, height;
     NetkWorkspace *workspace;
+    GdkRectangle unclipped_win_rect;
 
     workspace = netk_window_get_workspace (window);
     if (workspace == NULL)
@@ -593,10 +594,12 @@ get_window_rect (NetkWindow * window,
     if (height < 3)
         height = 3;
 
-    rect->x = x;
-    rect->y = y;
-    rect->width = width;
-    rect->height = height;
+    unclipped_win_rect.x = x;
+    unclipped_win_rect.y = y;
+    unclipped_win_rect.width = width;
+    unclipped_win_rect.height = height;
+
+    gdk_rectangle_intersect ((GdkRectangle *) workspace_rect, &unclipped_win_rect, rect);
 }
 
 static void
@@ -609,16 +612,18 @@ draw_window (GdkDrawable * drawable, GtkWidget * widget, NetkWindow * win,
 
     is_active = netk_window_is_active (win);
 
-    gdk_draw_rectangle (drawable,
-                        is_active ?
-                        widget->style->bg_gc[GTK_STATE_SELECTED] :
-                        widget->style->bg_gc[GTK_STATE_NORMAL],
-                        TRUE,
-                        winrect->x + 1, winrect->y + 1,
-                        winrect->width - 2, winrect->height - 2);
+    if ((winrect->width > 2) && (winrect->height > 2))
+    {
+	gdk_draw_rectangle (drawable,
+                            is_active ?
+                            widget->style->bg_gc[GTK_STATE_SELECTED] :
+                            widget->style->bg_gc[GTK_STATE_NORMAL],
+                            TRUE,
+                            winrect->x + 1, winrect->y + 1,
+                            winrect->width - 2, winrect->height - 2);
+    }
 
     icon = netk_window_get_icon (win);
-
     icon_w = icon_h = 0;
 
     if (icon)
@@ -691,13 +696,16 @@ draw_window (GdkDrawable * drawable, GtkWidget * widget, NetkWindow * win,
         }
     }
 
-    gdk_draw_rectangle (drawable,
-                        is_active ?
-                        widget->style->fg_gc[GTK_STATE_SELECTED] :
-                        widget->style->fg_gc[GTK_STATE_NORMAL],
-                        FALSE,
-                        winrect->x, winrect->y,
-                        winrect->width - 1, winrect->height - 1);
+    if ((winrect->width > 0) && (winrect->height > 0))
+    {
+	gdk_draw_rectangle (drawable,
+                            is_active ?
+                            widget->style->fg_gc[GTK_STATE_SELECTED] :
+                            widget->style->fg_gc[GTK_STATE_NORMAL],
+                            FALSE,
+                            winrect->x, winrect->y,
+                            winrect->width - 1, winrect->height - 1);
+    }
 }
 
 static int
@@ -1082,7 +1090,7 @@ netk_pager_button_press (GtkWidget * widget, GdkEventButton * event)
             {
                 if (event->button == 1)
                 {
-                    // netk_window_activate (win);
+                    /* netk_window_activate (win); */
                     pager->priv->drag_window = win;
                     pager->priv->drag_start_x = event->x;
                     pager->priv->drag_start_y = event->y;
@@ -1491,7 +1499,6 @@ static void
 window_geometry_changed_callback (NetkWindow * window, gpointer data)
 {
     NetkPager *pager = NETK_PAGER (data);
-
     gtk_widget_queue_draw (GTK_WIDGET (pager));
 }
 
