@@ -253,7 +253,10 @@ p_netk_get_text_property (Window xwindow, Atom atom)
     if (XGetTextProperty (gdk_display, xwindow, &text, atom))
     {
         retval = text_property_to_utf8 (&text);
-
+        if (retval)
+        {
+            utf8_string_remove_controls((gchar *) retval, -1, NULL);
+        }
         if (text.nitems > 0)
             XFree (text.value);
     }
@@ -328,7 +331,7 @@ p_netk_get_utf8_property (Window xwindow, Atom atom)
     if (err != Success || result != Success)
         return NULL;
 
-    if (type != utf8_string || format != 8 || nitems == 0)
+    if (type != utf8_string || format != 8 || nitems == 0 || !val)
     {
         if (val)
             XFree (val);
@@ -492,7 +495,7 @@ p_netk_get_utf8_list (Window xwindow, Atom atom)
                             &bytes_after, (guchar **)&val);
     err = p_netk_error_trap_pop ();
 
-    if (err != Success || result != Success)
+    if (err != Success || result != Success || !val)
         return NULL;
 
     if (type != utf8_string || format != 8 || nitems == 0)
@@ -1098,7 +1101,7 @@ p_netk_select_input (Window xwindow, int mask)
  * from metacity, please sync bugfixes
  */
 static gboolean
-find_largest_sizes (gulong * data, int nitems, int *width, int *height)
+find_largest_sizes (gulong * data, gulong nitems, int *width, int *height)
 {
     *width = 0;
     *height = 0;
@@ -1130,7 +1133,7 @@ find_largest_sizes (gulong * data, int nitems, int *width, int *height)
 }
 
 static gboolean
-find_best_size (gulong * data, int nitems, int ideal_width, int ideal_height,
+find_best_size (gulong * data, gulong nitems, int ideal_width, int ideal_height,
                 int *width, int *height, gulong ** start)
 {
     int best_w;
@@ -2369,7 +2372,7 @@ p_netk_get_desktop_margins (Screen * xscreen, p_DesktopMargins * margins)
     int real_format;
     int number;
     unsigned long items_read, items_left;
-    CARD32 *data = NULL;
+    unsigned long *data = NULL;
     int number_of_desktops;
 
     number = XScreenNumberOfScreen (xscreen);
@@ -2381,38 +2384,39 @@ p_netk_get_desktop_margins (Screen * xscreen, p_DesktopMargins * margins)
          (gdk_display, RootWindowOfScreen (xscreen),
           p_netk_atom_get ("_NET_WORKAREA"), 0L, 4 * number_of_desktops,
           False, XA_CARDINAL, &real_type, &real_format, &items_read,
-          &items_left, (guchar **)&data) == Success)
+          &items_left, (unsigned char **) &data) == Success)
         && (items_read >= 4 * number_of_desktops))
     {
-        int current_desktop;	
+        int current_desktop;
+
         if ((p_netk_get_cardinal
              (RootWindowOfScreen (xscreen),
               p_netk_atom_get ("_NET_CURRENT_DESKTOP"), &current_desktop))
             && (current_desktop < number_of_desktops))
         {
-            margins->left = data[4 * current_desktop];
-            margins->top = data[4 * current_desktop + 1];
-            margins->right =
-                XDisplayWidth (gdk_display,
-                               number) - (data[4 * current_desktop + 2] +
-                                          margins->left);
-            margins->bottom =
-                XDisplayHeight (gdk_display,
-                                number) - (data[4 * current_desktop + 3] +
-                                           margins->top);
+            margins->left = (int) 
+                (data[4 * current_desktop]);
+            margins->top = (int) 
+                (data[4 * current_desktop + 1]);
+            margins->right = (int) 
+                (XDisplayWidth (gdk_display, number) - 
+                    (data[4 * current_desktop + 2] + margins->left));
+            margins->bottom = (int)
+                (XDisplayHeight (gdk_display, number) - 
+                    (data[4 * current_desktop + 3] + margins->top));
         }
         else
         {
-            margins->left = data[4 * (number_of_desktops - 1)];
-            margins->top = data[4 * (number_of_desktops - 1) + 1];
-            margins->right =
-                XDisplayWidth (gdk_display,
-                               number) - (data[4 * (number_of_desktops - 1) +
-                                               2] + margins->left);
-            margins->bottom =
-                XDisplayHeight (gdk_display,
-                                number) - (data[4 * (number_of_desktops - 1) +
-                                                3] + margins->top);
+            margins->left = (int) 
+                (data[4 * (number_of_desktops - 1)]);
+            margins->top = (int) 
+                (data[4 * (number_of_desktops - 1) + 1]);
+            margins->right = (int)
+                (XDisplayWidth (gdk_display, number) - 
+                    (data[4 * (number_of_desktops - 1) + 2] + margins->left));
+            margins->bottom = (int)
+                (XDisplayHeight (gdk_display, number) - 
+                    (data[4 * (number_of_desktops - 1) + 3] + margins->top));
         }
         XFree (data);
         return TRUE;
@@ -2421,14 +2425,13 @@ p_netk_get_desktop_margins (Screen * xscreen, p_DesktopMargins * margins)
               (gdk_display, RootWindowOfScreen (xscreen),
                p_netk_atom_get ("GNOME_PANEL_DESKTOP_AREA"), 0L, 4L, False,
                XA_CARDINAL, &real_type, &real_format, &items_read,
-               &items_left, (guchar **)&data) == Success)
+               &items_left, (unsigned char **) &data) == Success)
              && (items_read >= 4))
     {
-        margins->left = data[0];
-        margins->top = data[1];
-        margins->right = data[2];
-        margins->bottom = data[3];
-	
+        margins->left = (int) data[0];
+        margins->top = (int) data[1];
+        margins->right = (int) data[2];
+        margins->bottom = (int) data[3];
         XFree (data);
         return TRUE;
     }
@@ -2445,17 +2448,17 @@ p_netk_get_desktop_margins (Screen * xscreen, p_DesktopMargins * margins)
 void
 p_netk_set_desktop_margins (Window xwindow, p_DesktopMargins * margins)
 {
-    CARD32 *data = NULL;
-    CARD32 *ptr = NULL;
+    unsigned long *data = NULL;
+    unsigned long *ptr = NULL;
 
-    data = g_new (CARD32, 4);
+    data = g_new0 (unsigned long, 4);
     ptr = data;
-    *ptr++ = margins->left;
-    *ptr++ = margins->right;
-    *ptr++ = margins->top;
-    *ptr++ = margins->bottom;
+    *ptr++ = (unsigned long) margins->left;
+    *ptr++ = (unsigned long) margins->right;
+    *ptr++ = (unsigned long) margins->top;
+    *ptr++ = (unsigned long) margins->bottom;
     XChangeProperty (gdk_display, xwindow, p_netk_atom_get ("_NET_WM_STRUT"),
-                     XA_CARDINAL, 32, PropModeReplace, (guchar *) data,
+                     XA_CARDINAL, 32, PropModeReplace, (unsigned char *) data,
                      4);
     g_free (data);
 }
